@@ -1,12 +1,12 @@
 package JSONAPI::Document::Builder::Relationships;
-$JSONAPI::Document::Builder::Relationships::VERSION = '1.7';
+$JSONAPI::Document::Builder::Relationships::VERSION = '1.8';
 =head1 NAME
 
 JSONAPI::Document::Builder::Relationships - Related Resource Document builder
 
 =head1 VERSION
 
-version 1.7
+version 1.8
 
 =head1 DESCRIPTION
 
@@ -98,10 +98,7 @@ sub build_links_document {
         Carp::confess('Missing required argument: api_url');
     }
 
-    my $relationship_type = lc $relationship;
-    if ($self->kebab_case_attrs) {
-        $relationship_type =~ s/_/-/g;
-    }
+    my $relationship_type = $self->format_type($relationship);
 
     my $data;
     my $rel_info = $row->result_source->relationship_info($relationship);
@@ -109,13 +106,13 @@ sub build_links_document {
         $data = [];
         my @rs = $row->$relationship->all();
         foreach my $related_row (@rs) {
-            push @$data, { id => $related_row->id, type => $relationship_type };
+            push @$data, { id => $related_row->id, type => $self->document_type($relationship_type) };
         }
     } else {
         if (my $related_row = $row->$relationship) {
             $data = {
                 id   => $related_row->id,
-                type => $self->document_type($relationship) };
+                type => $self->document_type($relationship_type) };
         }
     }
 
